@@ -1,16 +1,17 @@
 class Parameter:
 
-    def __init__(self, name: str, typehint: type = None, default: str = None):
-        # default=None literally means there is no default
-        # not that the default value is `None`
-        self.__name = name
+    def __init__(self, name: str, **kwargs):
+        # isn't really used to it's full potential right now
+        # we'll have to see if a good way to implement custom parameters is found
+        self._name = name
         # resolves <class 'str'> to str
-        self.__typehint = typehint.__name__ if typehint else None
-        self.__default = f"\"{default}\"" if default else None
+        self._default = repr(kwargs["default"]) if "default" in kwargs else None
+        self._typehint = kwargs["typehint"].__name__ if "typehint" in kwargs else None
 
     def __repr__(self):
-        return f"<{self.code()}>"
+        return f"<Parameter {self.code}>"
 
+    @property
     def code(self):
         if self.typehint and self.default:
             return f"{self.name}: {self.typehint} = {self.default}"
@@ -22,12 +23,12 @@ class Parameter:
 
     @property
     def name(self):
-        return self.__name
+        return self._name
 
     @property
     def typehint(self):
-        return self.__typehint
+        return self._typehint
 
     @property
     def default(self):
-        return self.__default
+        return self._default
